@@ -36,19 +36,18 @@ class KAudiocdModule : public AudiocdConfig
 public:
 
   KAudiocdModule(QWidget *parent=0, const char *name=0);
-    ~KAudiocdModule();
+  ~KAudiocdModule();
 
   QString quickHelp() const;
-  const KAboutData* aboutData() const;
 
 public slots:
-
   void defaults();
   void save();
   void load();
+  void load(bool useDefaults);
 
 private slots:
-
+  void updateExample();
   void slotConfigChanged();
   void slotEcEnable();
   void slotModuleChanged();
@@ -57,8 +56,10 @@ private:
   KConfig *config;
   bool configChanged;
 
+  int getBitrateIndex(int value);
+
   QPtrList<KConfigDialogManager> encoderSettings;
 };
 
-#endif
+#endif // KAUDIOCDCONFIG_H
 
