@@ -13,6 +13,9 @@
 
 #include "floatFrame.h"
 
+#include <iostream>
+
+using namespace std;
 
 FloatFrame::FloatFrame(int size) {
   data=new float[size];
@@ -26,7 +29,7 @@ FloatFrame::FloatFrame(int size) {
 
 
 FloatFrame::~FloatFrame() {
-  delete data;
+  delete [] data;
 }
 
 
