@@ -15,9 +15,8 @@
 #ifndef __PLUGININFO_H
 #define __PLUGININFO_H
 
-#include <iostream.h>
 #include "../util/dynBuffer.h"
-
+#include <kdemacros.h>
 
 /**
    Here we have the base class for all additional information
@@ -27,7 +26,7 @@
 */
 
 
-class PluginInfo {
+class KDE_EXPORT PluginInfo {
 
   int sec;
   DynBuffer* musicName;
