@@ -1,6 +1,6 @@
 #include <noatun/playlistsaver.h>
 #include <qdom.h>
-#include <netaccess.h>
+#include <kio/netaccess.h>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <noatun/app.h>
